BasicInfo class

Basic Info

Constructors

BasicInfo({bool? isPrivate, bool? isVerified, String? profilePic, int? followers, int? following, String? fullName, int? noOfPosts, String? bio})

Properties

bio ↔ String?
getter/setter pair
followers ↔ int?
getter/setter pair
following ↔ int?
getter/setter pair
fullName ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isPrivate ↔ bool?
getter/setter pair
isVerified ↔ bool?
getter/setter pair
noOfPosts ↔ int?
getter/setter pair
profilePic ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited