Img class

Img

Constructors

Img({String? id, Dimensions? dimensions, String? displayUrl, bool? isVideo, String? accessibilityCaption})

Properties

accessibilityCaption ↔ String?
getter/setter pair
dimensions ↔ Dimensions?
getter/setter pair
displayUrl ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
isVideo ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited