Post class

Constructors

Post({Dimensions? dimensions, String? displayUrl, String? caption, bool? hasNestedImages, bool? isVideo, int? likes, int? comments, List<Img>? images})

Properties

caption ↔ String?
getter/setter pair
comments ↔ int?
getter/setter pair
dimensions ↔ Dimensions?
getter/setter pair
displayUrl ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasNestedImages ↔ bool?
getter/setter pair
images ↔ List<Img>?
getter/setter pair
isVideo ↔ bool?
getter/setter pair
likes ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited