NextResponse class

Next Response

Constructors

NextResponse({Data? data, String? status})
NextResponse.fromJson(Map<String, dynamic> json)
from json
factory

Properties

data ↔ Data?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited