InstaApi class

Entry point of InstaApi

Constructors

InstaApi({Graphql? graphql})
InstaApi.fromJson(Map<String, dynamic> json)
from json
factory

Properties

graphql ↔ Graphql?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited