TentacledNode class

Graphql TentacledNode

Constructors

TentacledNode({String? typename, String? id, String? shortcode, Dimensions? dimensions, String? displayUrl, String? mediaPreview, Owner? owner, bool? isVideo, String? accessibilityCaption})
TentacledNode.fromJson(Map<String, dynamic> json)
from json
factory

Properties

accessibilityCaption ↔ String?
getter/setter pair
dimensions ↔ Dimensions?
getter/setter pair
displayUrl ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
isVideo ↔ bool?
getter/setter pair
mediaPreview ↔ String?
getter/setter pair
owner ↔ Owner?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortcode ↔ String?
getter/setter pair
typename ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited