User class

Constructors

User({String? biography, String? externalUrl, String? externalUrlLinkshimmed, Edge? edgeFollowedBy, bool? followedByViewer, Edge? edgeFollow, String? fullName, String? id, bool? isBusinessAccount, bool? isJoinedRecently, bool? isPrivate, bool? isVerified, String? profilePicUrl, String? profilePicUrlHd, bool? requestedByViewer, String? username, EdgeOwnerToTimelineMedia? edgeOwnerToTimelineMedia})
User.fromJson(Map<String, dynamic> json)
from json
factory

Properties

biography ↔ String?
getter/setter pair
edgeFollow ↔ Edge?
getter/setter pair
edgeFollowedBy ↔ Edge?
getter/setter pair
edgeOwnerToTimelineMedia ↔ EdgeOwnerToTimelineMedia?
getter/setter pair
externalUrl ↔ String?
getter/setter pair
externalUrlLinkshimmed ↔ String?
getter/setter pair
followedByViewer ↔ bool?
getter/setter pair
fullName ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
isBusinessAccount ↔ bool?
getter/setter pair
isJoinedRecently ↔ bool?
getter/setter pair
isPrivate ↔ bool?
getter/setter pair
isVerified ↔ bool?
getter/setter pair
profilePicUrl ↔ String?
getter/setter pair
profilePicUrlHd ↔ String?
getter/setter pair
requestedByViewer ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited